"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.persistFlow = void 0;
const tslib_1 = require("tslib");
const loggin_1 = require("../../../../core/loggin");
const path_1 = require("path");
const file_1 = require("../../../../core/file");
const fs_1 = require("fs");
const __1 = require("../../../..");
const utils_1 = require("../persist/utils");
const utils_2 = require("../report/utils");
const md_report_1 = require("../../../assert/utils/md-report");
function persistFlow(flow, { outPath, format, url }) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!format.length) {
            format = ['stdout'];
        }
        const jsonReport = yield flow.createFlowResult();
        const reducedReport = (0, __1.createReducedReport)(jsonReport);
        const results = [];
        if (format.includes('json')) {
            results.push({ format: 'json', out: JSON.stringify(jsonReport) });
        }
        let mdReport = undefined;
        if (format.includes('md')) {
            mdReport = (0, md_report_1.generateMdReport)(reducedReport);
            results.push({ format: 'md', out: mdReport });
        }
        if (format.includes('stdout')) {
            if (!mdReport) {
                mdReport = (0, utils_1.generateStdoutReport)(reducedReport);
            }
            (0, loggin_1.log)(mdReport + '');
        }
        if (format.includes('html')) {
            const htmlReport = yield flow.generateReport();
            results.push({ format: 'html', out: htmlReport });
        }
        if (!(0, fs_1.existsSync)(outPath)) {
            try {
                (0, fs_1.mkdirSync)(outPath, { recursive: true });
            }
            catch (e) {
                // @TODO use a constant instead of a string e.g. `OUT_PATH_NO_DIR_ERROR(dir)`
                throw new Error(`outPath: ${outPath} is no directory`);
            }
        }
        const fileName = (0, utils_2.toReportName)(url, flow.name, reducedReport);
        const fileNames = results.map((result) => {
            const filePath = (0, path_1.join)(outPath, `${fileName}.${result.format}`);
            (0, file_1.writeFile)(filePath, result.out);
            (0, loggin_1.logVerbose)(`Report path: ${filePath}.`);
            return filePath;
        });
        return fileNames;
    });
}
exports.persistFlow = persistFlow;
//# sourceMappingURL=persist-flow.js.map