"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parse = void 0;
const replay_1 = require("@puppeteer/replay");
const utils_1 = require("./utils");
function parse(recordingJson) {
    // custom events to exclude from the default parser
    const ufArr = [];
    // filter out user-flow specific actions
    const steps = recordingJson.steps.filter((value, index) => {
        if ((0, utils_1.isMeasureType)(value === null || value === void 0 ? void 0 : value.type)) {
            ufArr[index] = value;
            return false;
        }
        return true;
    });
    // parse the clean steps
    const parsed = (0, replay_1.parse)(Object.assign(Object.assign({}, recordingJson), { steps }));
    // add in user-flow specific actions
    ufArr.forEach((value, index) => {
        value && (parsed.steps.splice(index, 0, value));
    });
    // parse customEvents from our stringify function
    parsed.steps = parsed.steps.map((step) => {
        if (step.type === replay_1.StepType.CustomStep && (0, utils_1.isMeasureType)(step.name)) {
            const { name: type, parameters } = step;
            return { type, parameters };
        }
        return step;
    });
    return parsed;
}
exports.parse = parse;
//# sourceMappingURL=parse.js.map