"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.collectFlow = void 0;
const tslib_1 = require("tslib");
const loggin_1 = require("../../../../core/loggin");
const puppeteer = require("puppeteer");
const path_1 = require("path");
// @ts-ignore
const api_1 = require("lighthouse/lighthouse-core/fraggle-rock/api");
const dryRun_1 = require("../../../../commands/collect/options/dryRun");
const user_flow_mock_1 = require("./user-flow.mock");
const cli_mode_1 = require("../../../../global/cli-mode/cli-mode");
const config_1 = require("../config");
function collectFlow(cliOption, userFlowProvider) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let { path, 
        // object containing the LH setting for budgets
        // @TODO refactor typing
        flowOptions, interactions, launchOptions } = userFlowProvider;
        let globalLhCfg = (0, config_1.getLhConfigFromArgv)(cliOption);
        const lhConfig = (0, config_1.mergeLhConfig)(globalLhCfg, flowOptions === null || flowOptions === void 0 ? void 0 : flowOptions.config);
        flowOptions.config = lhConfig;
        const browser = yield puppeteer.launch(parseLaunchOptions(launchOptions));
        const page = yield browser.newPage();
        (0, loggin_1.logVerbose)(`Collect: ${flowOptions.name} from URL ${cliOption.url}`);
        (0, loggin_1.logVerbose)(`User-flow path: ${(0, path_1.normalize)(path)}`);
        let start = Date.now();
        const flow = !(0, dryRun_1.get)() ? yield (0, api_1.startFlow)(page, flowOptions) : new user_flow_mock_1.UserFlowMock(page, flowOptions);
        // run custom interactions
        yield interactions({ flow, page, browser, collectOptions: cliOption });
        (0, loggin_1.logVerbose)(`Duration: ${flowOptions.name}: ${(Date.now() - start) / 1000}`);
        yield browser.close();
        return flow;
    });
}
exports.collectFlow = collectFlow;
function parseLaunchOptions(launchOptions) {
    // object containing the options for puppeteer/chromium
    launchOptions = launchOptions || {
        // has to be false to run in the CI because of a bug :(
        // https://github.com/puppeteer/puppeteer/issues/8148
        headless: false,
        // hack for dryRun => should get fixed inside user flow in future
        defaultViewport: { isMobile: true, isLandscape: false, width: 800, height: 600 }
    };
    const cliMode = (0, cli_mode_1.detectCliMode)();
    // cli mode is "CI" or "SANDBOX"
    if (cliMode !== 'DEFAULT' && launchOptions) {
        const headlessMode = true;
        (0, loggin_1.logVerbose)(`Set options#headless to ${headlessMode} in puppeteer#launch as we are running in ${cliMode} mode`);
        launchOptions.headless = headlessMode;
    }
    return launchOptions;
}
//# sourceMappingURL=collect-flow.js.map