"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveBudgetsFromLhr = void 0;
const constants_1 = require("./constants");
const loggin_1 = require("../../core/loggin");
function deriveBudgetsFromLhr(flow) {
    var _a;
    const budgetObject = {};
    if ((_a = flow === null || flow === void 0 ? void 0 : flow.steps[0].lhr) === null || _a === void 0 ? void 0 : _a.audits) {
        if (flow.steps[0].lhr.audits['resource-summary']) {
            const resourceSummary = flow.steps[0].lhr.audits['resource-summary'];
            budgetObject.resourceSizes = resourceSummary.details.items
                .filter(({ resourceType }) => constants_1.TransferSizeResourceTypeBudgets.includes(resourceType))
                .map(({ resourceType, transferSize }) => ({
                resourceType,
                budget: transferSize
            }));
            budgetObject.resourceCounts = resourceSummary.details.items
                .filter(({ resourceType }) => constants_1.RequestCountResourceTypeBudgets.includes(resourceType))
                .map(({ resourceType, requestCount }) => ({
                resourceType,
                budget: requestCount
            }));
        }
        else {
            (0, loggin_1.logVerbose)(`The lighthouse report does not contain a "resource-summary" audit`);
        }
        budgetObject.timings = [];
        if (flow.steps[0].lhr.audits['cumulative-layout-shift']) {
            budgetObject.timings.push({
                'metric': 'cumulative-layout-shift',
                'budget': flow.steps[0].lhr.audits['cumulative-layout-shift'].details.items[0].totalCumulativeLayoutShift
            });
        }
        else {
            (0, loggin_1.logVerbose)(`The lighthouse report does not contain a "cumulative-layout-shift" audit`);
        }
        if (flow.steps[0].lhr.audits['largest-contentful-paint']) {
            budgetObject.timings.push({
                'metric': 'largest-contentful-paint',
                'budget': parseInt(flow.steps[0].lhr.audits['largest-contentful-paint'].numericValue)
            });
        }
        else {
            (0, loggin_1.logVerbose)(`The lighthouse report does not contain a "largest-contentful-paint" audit`);
        }
    }
    return [budgetObject];
}
exports.deriveBudgetsFromLhr = deriveBudgetsFromLhr;
//# sourceMappingURL=derive-budgets-from-lhr.js.map