"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleBudgetsGeneration = exports.generateLgBudgets = void 0;
const tslib_1 = require("tslib");
const path_1 = require("path");
const file_1 = require("../../../core/file");
const loggin_1 = require("../../../core/loggin");
const fs_1 = require("fs");
const constants_1 = require("../constants");
const behaviors_1 = require("../../../core/processing/behaviors");
const derive_budgets_from_lhr_1 = require("../derive-budgets-from-lhr");
function generateLgBudgets(cliCfg) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const destPath = process.cwd();
        const targetFileName = 'budget.json';
        let fileContent = '';
        if ((0, file_1.readFile)(targetFileName) !== '') {
            (0, loggin_1.logVerbose)(`Budgets ${targetFileName} already generated.`);
            return Promise.resolve(cliCfg);
        }
        if (!cliCfg.lhr) {
            const tplFileName = constants_1.BudgetsExampleMap['budgets'];
            const exampleSourceLocation = (0, path_1.join)(__dirname, '..', 'static', tplFileName);
            fileContent = (0, file_1.readFile)(exampleSourceLocation, { fail: true }).toString();
            (0, loggin_1.logVerbose)('New budgets used');
        }
        else {
            const lhrJson = (0, file_1.readFile)(cliCfg.lhr);
            if (lhrJson === '') {
                throw new Error(`Lighthouse report ${cliCfg.lhr} to derive budgets from is not given.`);
            }
            fileContent = JSON.stringify((0, derive_budgets_from_lhr_1.deriveBudgetsFromLhr)(JSON.parse(lhrJson)));
            (0, loggin_1.logVerbose)('Budgets derived from lhr');
        }
        const exampleDestination = (0, path_1.join)(destPath, targetFileName);
        if (!(0, fs_1.existsSync)(destPath)) {
            (0, fs_1.mkdirSync)(destPath, { recursive: true });
            (0, loggin_1.logVerbose)(`setup budgets folder ${destPath}`);
        }
        (0, file_1.writeFile)(exampleDestination, fileContent);
        (0, loggin_1.log)(`Setup budgets ${exampleDestination} successfully`);
        return Promise.resolve(cliCfg);
    });
}
exports.generateLgBudgets = generateLgBudgets;
function handleBudgetsGeneration({ generateBudgets, lhr }) {
    return (0, behaviors_1.ifThenElse)(
    // if `generateBudgets` is used
    () => !!generateBudgets, 
    // generate the file => else do nothing
    (cfg) => generateLgBudgets(Object.assign(Object.assign({}, cfg), { lhr })));
}
exports.handleBudgetsGeneration = handleBudgetsGeneration;
//# sourceMappingURL=generate-lh-budgets.js.map