"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleFlowGeneration = exports.generateUserFlow = exports.userflowIsNotCreated = exports.getExamplePathDest = void 0;
const tslib_1 = require("tslib");
const path_1 = require("path");
const file_1 = require("../../../core/file");
const loggin_1 = require("../../../core/loggin");
const fs_1 = require("fs");
const constants_1 = require("../constants");
const behaviors_1 = require("../../../core/processing/behaviors");
const prompt_1 = require("../../../core/prompt");
const loggin_2 = require("../../../core/loggin");
const generateFlow_constants_1 = require("../options/generateFlow.constants");
const exampleName = 'basic-navigation';
function getExamplePathDest(flowExample, folder) {
    const fileName = constants_1.FlowExampleMap[flowExample];
    return (0, path_1.join)(folder, fileName);
}
exports.getExamplePathDest = getExamplePathDest;
const userflowIsNotCreated = (cfg) => Promise.resolve(cfg ? (0, file_1.readFile)(getExamplePathDest(exampleName, cfg.collect.ufPath)) === '' : false);
exports.userflowIsNotCreated = userflowIsNotCreated;
function generateUserFlow(cliCfg) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const ufPath = cliCfg.collect.ufPath;
        // DX create directory if it does ot exist
        try {
            (0, fs_1.readdirSync)(ufPath);
        }
        catch (e) {
            (0, fs_1.mkdirSync)(ufPath, { recursive: true });
        }
        const tplFileName = constants_1.FlowExampleMap[exampleName];
        const exampleSourceLocation = (0, path_1.join)(__dirname, '..', 'static', tplFileName);
        const exampleDestination = (0, path_1.join)(ufPath, tplFileName);
        if ((0, file_1.readFile)(exampleDestination) !== '') {
            (0, loggin_2.logVerbose)(`User flow ${exampleName} already generated under ${exampleDestination}.`);
            return Promise.resolve(cliCfg);
        }
        const fileContent = (0, file_1.readFile)(exampleSourceLocation, { fail: true }).toString();
        (0, file_1.writeFile)(exampleDestination, fileContent);
        (0, loggin_1.log)(`setup user-flow for basic navigation in ${ufPath} successfully`);
        return Promise.resolve(cliCfg);
    });
}
exports.generateUserFlow = generateUserFlow;
function handleFlowGeneration({ generateFlow, interactive }) {
    return (0, behaviors_1.ifThenElse)(
    // if `withFlow` is not used in the CLI is in interactive mode
    () => interactive == true && generateFlow === undefined, 
    // Prompt for flow generation
    (0, prompt_1.askToSkip)(generateFlow_constants_1.PROMPT_INIT_GENERATE_FLOW, generateUserFlow, 
    // if the flow is not created already, otherwise skip creation
    { precondition: exports.userflowIsNotCreated }), 
    // else `withFlow` is used and true
    (0, behaviors_1.ifThenElse)(() => !!generateFlow, 
    // generate the file => else do nothing
    generateUserFlow));
}
exports.handleFlowGeneration = handleFlowGeneration;
//# sourceMappingURL=generate-userflow.js.map