"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCliOptionsFromRcConfig = exports.updateRcConfig = exports.readRcConfig = void 0;
const file_1 = require("../../core/file");
const loggin_1 = require("../../core/loggin");
const options_1 = require("../options");
function readRcConfig(rcPath = '', options) {
    let { fail, fallback } = options || {};
    fallback = fallback || {};
    rcPath = rcPath || options_1.globalOptions.getRcPath();
    let repoConfigJson = (0, file_1.readFile)(rcPath, { ext: 'json', fail: !!fail });
    if (!repoConfigJson) {
        repoConfigJson = fallback;
    }
    return repoConfigJson;
}
exports.readRcConfig = readRcConfig;
function updateRcConfig(config, rcPath = '') {
    rcPath = rcPath || options_1.globalOptions.getRcPath();
    // NOTICE: this is needed for better git flow.
    // Touch a file only if needed
    if (JSON.stringify(readRcConfig()) !== JSON.stringify(config)) {
        (0, file_1.writeFile)(rcPath, JSON.stringify(config));
        (0, loggin_1.logVerbose)(`Update config under ${rcPath} to`, config);
    }
}
exports.updateRcConfig = updateRcConfig;
function getCliOptionsFromRcConfig(rcPath) {
    const { collect, persist, assert } = readRcConfig(rcPath || options_1.globalOptions.getRcPath());
    return Object.assign(Object.assign(Object.assign({}, collect), persist), assert);
}
exports.getCliOptionsFromRcConfig = getCliOptionsFromRcConfig;
//# sourceMappingURL=index.js.map